@@ -100,7 +100,9 @@ func init() {
 		"rand":                  "rand_commands_docgen.go",
 		"read":                  "read_commands_docgen.go",
 		"regexp":                "regexp_commands_docgen.go",
+		"return":                "return_commands_docgen.go",
 		"right":                 "right_commands_docgen.go",
+		"round":                 "round_commands_docgen.go",
 		"runmode":               "runmode_commands_docgen.go",
 		"runtime":               "runtime_commands_docgen.go",
 		"rx":                    "rx_commands_docgen.go",
