@@ -4,13 +4,11 @@
 package main
 
 import (
-	"fmt"
 	"os"
 	"runtime"
 	"runtime/pprof"
 
 	"github.com/lmorg/murex/lang"
-	"github.com/lmorg/murex/lang/tty"
 )
 
 const (
@@ -25,7 +23,7 @@ func init() {
 
 func cpuProfile() func() {
 	if fCpuProfile != "" {
-		fmt.Fprintf(tty.Stderr, "Writing CPU profile to '%s'\n", fCpuProfile)
+		//fmt.Fprintf(tty.Stderr, "Writing CPU profile to '%s'\n", fCpuProfile)
 
 		f, err := os.Create(fCpuProfile)
 		if err != nil {
@@ -41,7 +39,7 @@ func cpuProfile() func() {
 				panic(err)
 			}
 
-			fmt.Fprintf(tty.Stderr, "CPU profile written to '%s'\n", fCpuProfile)
+			//fmt.Fprintf(tty.Stderr, "CPU profile written to '%s'\n", fCpuProfile)
 		}
 	}
 
@@ -50,7 +48,7 @@ func cpuProfile() func() {
 
 func memProfile() func() {
 	if fMemProfile != "" {
-		fmt.Fprintf(tty.Stderr, "Writing memory profile to '%s'\n", fMemProfile)
+		//fmt.Fprintf(tty.Stderr, "Writing memory profile to '%s'\n", fMemProfile)
 
 		f, err := os.Create(fMemProfile)
 		if err != nil {
@@ -65,7 +63,7 @@ func memProfile() func() {
 			if err = f.Close(); err != nil {
 				panic(err)
 			}
-			fmt.Fprintf(tty.Stderr, "Memory profile written to '%s'\n", fMemProfile)
+			//fmt.Fprintf(tty.Stderr, "Memory profile written to '%s'\n", fMemProfile)
 		}
 	}
 
