@@ -19,11 +19,15 @@ func (rl *Instance) getHintText() {
 }
 
 func (rl *Instance) writeHintText(resetCursorPos bool) {
-	if len(rl.hintText) == 0 {
+	if rl.HintText == nil {
 		rl.hintY = 0
 		return
 	}
 
+	if len(rl.hintText) == 0 {
+		rl.hintText = []rune{' '}
+	}
+
 	hintText := string(rl.hintText)
 
 	rl.tabMutex.Lock()
@@ -67,14 +71,16 @@ func (rl *Instance) writeHintText(resetCursorPos bool) {
 		_, lineY := rl.lineWrapCellLen()
 		posX, posY := rl.lineWrapCellPos()
 		y := lineY - posY
-		moveCursorDown(y)
+		move := moveCursorDownStr(y)
 
-		print("\r\n" + rl.HintFormatting + hintText + seqReset)
+		move += "\r\n" + rl.HintFormatting + hintText + seqReset
 
-		moveCursorUp(rl.hintY + lineY - posY)
-		moveCursorBackwards(rl.termWidth)
-		moveCursorForwards(posX)
+		move += moveCursorUpStr(rl.hintY + lineY - posY)
+		move += moveCursorBackwardsStr(rl.termWidth)
+		move += moveCursorForwardsStr(posX)
+		print(move)
 	}
+
 }
 
 func (rl *Instance) resetHintText() {
