@@ -1,9 +1,8 @@
+//go:build !js
 // +build !js
 
 package readline
 
-import "os"
-
 func read(b []byte) (int, error) {
-	return os.Stdin.Read(b)
+	return replica.Read(b)
 }
