@@ -60,8 +60,8 @@ func TestViDeleteByAdjustLogicNoPanic(t *testing.T) {
 
 	for _, test := range tests {
 		rl := NewInstance()
-		rl.line = []rune(test.Line)
-		rl.pos = test.Pos
+		rl.line.Set([]rune(test.Line))
+		rl.line.SetRunePos(test.Pos)
 		rl.viDeleteByAdjustLogic(&test.Adjust)
 	}
 }
